**7. Release Notes**
=================================

The latest and previous versions of PowNet are listed below. Please,
check the `release
notes <https://github.com/Critical-Infrastructure-Systems-Lab/PowNet/releases>`__ for
a list of modifications made in each version. 

.. note::

   Please note that the latest version (v2.0) features substantial changes with respect to the v1.x versions, whose development is no longer supported.

Current version
---------------

-  PowNet v2.0

Previous versions
-----------------

-  PowNet v1.3
   (`GitHub <https://github.com/kamal0013/PowNet/tree/v1.3>`__ | `Zenodo <https://zenodo.org/record/4688309#.YHc5euhKguU>`__)

-  PowNet v1.2
   (`GitHub <https://github.com/kamal0013/PowNet/tree/v1.2>`__ | `Zenodo <https://zenodo.org/record/4020167#.X1hqrGhKguU>`__)

-  PowNet v1.1
   (`GitHub <https://github.com/kamal0013/PowNet/tree/v1.1>`__ | `Zenodo <https://zenodo.org/record/3756750>`__)
